@@ -129,32 +129,32 @@ class SimpleClimateModel:
         '''       
         # write to file if required
         Filename = self._GetParameter('Write CH4 concentrations to file')
-        if (Filename != None) and (Filename != ""):
+        if Filename:
             self._writeConcsToFile('CH4', Filename)
         
         # plot CH4 concentrations
         switch = self._GetParameter('Plot CH4 concentrations to file')
-        if (switch != None) and (switch != ""):
+        if switch:
             self.plotConcs('CH4', switch)
             
         # write to file if required
         Filename = self._GetParameter('Write N20 concentrations to file')
-        if (Filename != None) and (Filename != ""):
+        if Filename:
             self._writeConcsToFile('N2O', Filename)
         
         # plot N2O concentrations
         switch = self._GetParameter('Plot N2O concentrations to file')
-        if (switch != None) and (switch != ""):
+        if switch:
             self.plotConcs('N2O', switch)
         
         # write to file if required
         Filename = self._GetParameter('Write CO2 concentrations to file')
-        if (Filename != None) and (Filename != ""):
+        if Filename:
             self._writeConcsToFile('CO2', Filename)
         
         # plot CO2 concentrations
         switch = self._GetParameter('Plot CO2 concentrations to file')
-        if (switch != None) and (switch != ""):
+        if switch:
             self.plotConcs('CO2', switch)
 
     
@@ -304,7 +304,7 @@ class SimpleClimateModel:
         '''
         try:
             Filename = self._GetParameter('Filename for temperature change')
-            if (Filename == None) or (Filename == ""):
+            if not Filename:
                 raise SCMError('You need to provide a filename in the Parameter set up file!') 
             # write values to file
             writer = open(Filename, 'w')
@@ -315,7 +315,7 @@ class SimpleClimateModel:
             
             # Plot temperature change and save figure to file if required
             PlotFile = self._GetParameter('Plot temperature change')
-            if (PlotFile != None) and (PlotFile !=''):
+            if PlotFile:
                 x = np.arange(self.startYr,self.endYr+1)
                 fig = plt.figure(1)
                 plt.plot(x,self.temperatureChange)
@@ -332,7 +332,7 @@ class SimpleClimateModel:
                 
             
             SeaLevelFilename = self._GetParameter('Filename for sea level change')
-            if (SeaLevelFilename == None) or (SeaLevelFilename == ""):
+            if not SeaLevelFilename:
                 raise SCMError('You need to provide a filename in the Parameter set up file!') 
             # write values to file
             writer = open(SeaLevelFilename, 'w')
@@ -343,7 +343,7 @@ class SimpleClimateModel:
             
             # Plot temperature change and save figure to file if required
             PlotFile = self._GetParameter('Plot sea level change')
-            if (PlotFile != None) and (PlotFile !=''):
+            if PlotFile:
                 x = np.arange(self.startYr,self.endYr+1)
                 fig = plt.figure(1)
                 plt.plot(x,self.seaLevelChange)
